🍪 Cookies
==========

Cookies stored by the crawlers can be seen from the :doc:`../admin_ui`, by clicking on ``Cookies``.

.. image:: ../../tests/robotframework/screenshots/cookies_list.png
   :class: sosse-screenshot

You can find which cookie applies to a specific web page by typing its URL in the search bar.

Cookies import
--------------

Cookies can be imported using the ``Import cookies`` link.

.. image:: ../../tests/robotframework/screenshots/cookies_import.png
   :class: sosse-screenshot

They should be entered using the `Netscape cookie format <https://curl.se/docs/http-cookies.html#cookies-saved-to-disk>`_.
Tools like `Cookie editor <https://cookie-editor.com/>`_ can be used to export cookies from a browser in a compatible manner.
